Module proof

Module proof 

Re-exports

pub use crate::consistency::ConsistencyProof;
pub use crate::consistency::reconstruct_consistency_roots;
pub use crate::consistency::verify_consistency;

Structs

InclusionProof
Inclusion proof: path from a leaf to the root.
ProofStep
A single level in a Merkle proof path.

Functions

constant_time_eq
Timing-safe comparison of two byte slices.
reconstruct_inclusion_root
Reconstruct the raw root from an inclusion proof path and its trusted skeleton.
verify_inclusion
Verify an inclusion proof against a consumer-supplied skeleton.
verify_inclusion_path_structure
Validate that the trailing steps of an inclusion proof path match the consumer-supplied skeleton.