pub trait Hydrate {
type Output;
// Required method
fn hydrate(self, file: &Arc<PathBuf>) -> Result<Self::Output, Error>;
}Expand description
Hydrate is used to translate a type to a
Result
It is possible to error when merging if a field is defined as multiple, incompatible data structures.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".