Environment

Struct Environment 

pub struct Environment {
    pub name: Name,
    pub extends: Option<EnvironmentExtends>,
    pub runners: Option<Vec<RunnerRegistration>>,
    pub resolvers: Option<Vec<ResolverRegistration>>,
    pub debug: Option<Vec<DebugRegistration>>,
    pub stop_timeout_ms: Option<StopTimeoutMs>,
}
Example:

environments: [
    {
        name: "test-env",
        extends: "realm",
        runners: [
            {
                runner: "gtest-runner",
                from: "#gtest",
            },
        ],
        resolvers: [
            {
                resolver: "full-resolver",
                from: "parent",
                scheme: "fuchsia-pkg",
            },
        ],
    },
],

Fields

name: Name

The name of the environment, which is a string of one or more of the following characters: a-z, 0-9, _, ., -. The name identifies this environment when used in a reference.

extends: Option<EnvironmentExtends>

How the environment should extend this realm’s environment.

  • realm: Inherit all properties from this component’s environment.
  • none: Start with an empty environment, do not inherit anything.
runners: Option<Vec<RunnerRegistration>>

The runners registered in the environment. An array of objects with the following properties:

resolvers: Option<Vec<ResolverRegistration>>

The resolvers registered in the environment. An array of objects with the following properties:

debug: Option<Vec<DebugRegistration>>

Debug protocols available to any component in this environment acquired through use from debug.

stop_timeout_ms: Option<StopTimeoutMs>

The number of milliseconds to wait, after notifying a component in this environment that it should terminate, before forcibly killing it. This field is required if the environment extends from none.