Re-exports
pub use crate::consistency::ConsistencyProof;pub use crate::consistency::reconstruct_consistency_roots;pub use crate::consistency::verify_consistency;
Structs
- Inclusion
Proof - Inclusion proof: path from a leaf to the root.
- Proof
Step - A single level in a Merkle proof path.
Functions
- constant_
time_ eq - Timing-safe comparison of two byte slices.
- reconstruct_
inclusion_ root - Reconstruct the raw root from an inclusion proof path and its trusted skeleton.
- verify_
inclusion - Verify an inclusion proof against a consumer-supplied skeleton.
- verify_
inclusion_ path_ structure - Validate that the trailing steps of an inclusion proof path match the
consumer-supplied
skeleton.