Hydrate

Trait Hydrate 

pub trait Hydrate {
    type Output;

    // Required method
    fn hydrate(self, file: &Arc<PathBuf>) -> Result<Self::Output, Error>;
}
Hydrate is used to translate a type to a Result type. The ContextSpanned type is used by validation.

It is possible to error when merging if a field is defined as multiple, incompatible data structures.

Required Associated Types

Required Methods

fn hydrate(self, file: &Arc<PathBuf>) -> Result<Self::Output, Error>

Implementors